"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Assets {
    static getAccountAttribute(account, name) {
        return account[name];
    }
    static async getAssets(client, address) {
        const account = await client.accountInformation(address).do();
        const assets = Assets.getAccountAttribute(account, 'assets');
        return assets;
    }
    static async findAsset(client, address, asaId) {
        const assets = (await Assets.getAssets(client, address));
        return assets.find((asa) => asa['asset-id'] === asaId);
    }
    static async getCirculatingSupply(client, asaId) {
        const asa = await client.getAssetByID(asaId).do();
        const asaParams = asa['params'];
        const reserve = asaParams.reserve;
        const reserveBalance = await Assets.getAsaBalance(client, reserve, asaId);
        const total = asaParams.total;
        const circulating = total - reserveBalance;
        return circulating;
    }
    static async getCreatedAssets(client, address) {
        const account = await client.accountInformation(address).do();
        const createdAssets = Assets.getAccountAttribute(account, 'created-assets');
        return createdAssets;
    }
    static async getAsaBalance(client, address, asaId) {
        const asa = await Assets.findAsset(client, address, asaId);
        const amount = asa ? asa['amount'] : 0;
        return amount;
    }
    static async isOptIn(client, address, asaId) {
        const asa = await Assets.findAsset(client, address, asaId);
        const amount = asa ? asa['amount'] : -1;
        return amount != -1;
    }
    static async getTokenCirculatingSupply(client, asaId) {
        const circulating = await Assets.getCirculatingSupply(client, asaId);
        return circulating;
    }
}
exports.default = Assets;
//# sourceMappingURL=assets.js.map