"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Reader = exports.ReaderOnlyClient = void 0;
const accounts_1 = require("./accounts/accounts");
const transactions_1 = require("./transactions/transactions");
const apps_1 = require("./apps/apps");
const assets_1 = require("./assets/assets");
const metadata_1 = require("./assets/metadata");
class ReaderOnlyClient {
    constructor(provider) {
        this.provider = provider;
    }
    async validateAddress(address) {
        return accounts_1.default.validateAddress(address);
    }
    async getBalanceAlgos(address) {
        return accounts_1.default.getBalanceAlgos(this.provider.client, address);
    }
    async getBalanceMicroalgos(address) {
        return accounts_1.default.getBalanceMicroalgos(this.provider.client, address);
    }
    async getMinBalance(address) {
        return accounts_1.default.getMinBalance(this.provider.client, address);
    }
    async getCreatedAssets(address) {
        return assets_1.default.getCreatedAssets(this.provider.client, address);
    }
    async getAsaBalance(address, asaId) {
        return assets_1.default.getAsaBalance(this.provider.client, address, asaId);
    }
    async isOptIn(address, asaId) {
        return assets_1.default.isOptIn(this.provider.client, address, asaId);
    }
    async getTokenCirculatingSupply(asaId) {
        return assets_1.default.getTokenCirculatingSupply(this.provider.client, asaId);
    }
    async getAssetIdByMetadataHash(hash, creator) {
        return metadata_1.default.getAssetIdByMetadataHash(this.provider.client, hash, creator);
    }
    async getPendingTx(address) {
        return transactions_1.default.getPendingTxByAddress(this.provider.client, address);
    }
    async thereArePendingTxs(address) {
        return transactions_1.default.thereArePendingTxs(this.provider.client, address);
    }
    async getGlobalState(addr, appId) {
        return apps_1.default.getGlobalState(this.provider.client, addr, appId);
    }
}
exports.ReaderOnlyClient = ReaderOnlyClient;
class Reader extends ReaderOnlyClient {
    constructor(provider) {
        super(provider);
        this.provider = provider;
    }
    async getAssetMetadata(assetId) {
        return metadata_1.default.getAssetMetadata(this.provider.indexer, assetId);
    }
}
exports.Reader = Reader;
//# sourceMappingURL=reader.js.map